# Plagiat (Py)
Library untuk memeriksa tingkat Plagiarisme menggunakan Bahasa Python.

### Instalasi
```
pip install plagiat
```

### Contoh Penggunaan

```Python
import plagiat

```

### TODO
Library ini hanya untuk keperluan pembuatan tugas Data Science.